@@ -1,5 +1,6 @@
 from typing import Callable
 
+from reprit import serializers
 from reprit.base import generate_repr
 
 from ground.core.hints import (Contour,
@@ -23,6 +24,7 @@ class Context:
         self._region_signed_area = region_signed_area
 
     __repr__ = generate_repr(__init__,
+                             argument_serializer=serializers.complex_,
                              with_module_name=True)
 
 
